# Kanka for python

Hello there. This library/wrapper/whatever will help you a lot with dealing with kanka's API. For information about kanka, have a look at kanka.io.

For contacting me, join the kanka discord channel (https://discord.gg/rhsyZJ4) or PM me on Telegram (https://t.me/poolitzer).

Have a good day.


DISCLAIMER:

This is obviously a dev release. Don't use it now, things won't work lol.